pub enum BindError {
RuntimeDirNotSet,
PermissionDenied,
AlreadyInUse,
Io(Error),
}Expand description
Error that can occur when trying to bind a ListeningSocket
Variants
RuntimeDirNotSet
The Environment variable XDG_RUNTIME_DIR is not set
PermissionDenied
The application was not able to create a file in XDG_RUNTIME_DIR
AlreadyInUse
The requested socket name is already in use
Io(Error)
Some other IO error occured