Display

Struct Display 

pub struct Display<State: 'static> { /* private fields */ }
The Wayland display

This struct is the core of your Wayland compositor. You’ll use it in your event loop to drive the protocol processing of all your clients. All other interactions with the protocol itself are done through the DisplayHandle struct, on which the State type parameter is erased for convenience.

Usage

The main loop of a Wayland compositor generally needs to wait on several sources of events, using tools like epoll (on Linux). The Wayland display can be integrated in this mechanism by getting the file descriptor as from .backend().poll_fd() and invoking the dispatch_clients() method whenever it becomes readable.

To ensure all clients receive the events your compositor sends them, you also need to regularly invoke the flush_clients() method, which will write the outgoing buffers into the sockets.

Implementations

Source

impl<State: 'static> Display<State>

pub fn new() -> Result<Display<State>, InitError>

Create a new Wayland display

Can only fail if both the server_system and dlopen features of wayland-backend were enabled, and the libwayland-server.so library could not be found.

pub fn handle(&self) -> DisplayHandle

Retrieve a DisplayHandle for this Display.

This is the type with which all of your interactions with the Wayland protocol are done.

pub fn dispatch_clients(&mut self, state: &mut State) -> Result<usize>

Dispatch all requests received from clients to their respective callbacks.

The state argument is the main state of your compositor, which will be accessible from most of your callbacks.

pub fn flush_clients(&mut self) -> Result<()>

Flush outgoing buffers into their respective sockets.

pub fn backend(&mut self) -> &mut Backend<State>

Access the underlying Backend of this Display